<a id="aea.test_tools.network"></a>

# aea.test`_`tools.network

Helper utils.

<a id="aea.test_tools.network.get_unused_tcp_port"></a>

#### get`_`unused`_`tcp`_`port

```python
def get_unused_tcp_port() -> int
```

Get an unused TCP port.

<a id="aea.test_tools.network.get_host"></a>

#### get`_`host

```python
def get_host() -> str
```

Get the host.

<a id="aea.test_tools.network.is_port_in_use"></a>

#### is`_`port`_`in`_`use

```python
def is_port_in_use(port: int) -> bool
```

Check if port is in use

